env_from

Function env_from 

pub fn env_from(
    names: &[String],
) -> Result<BTreeMap<String, String>, SpawnError>
Resolves the variables an agent named, from the supervisor’s own environment.

Errors

Returns SpawnError::MissingEnv for the first name that is not set.