pub fn env_from(
names: &[String],
) -> Result<BTreeMap<String, String>, SpawnError>Expand description
Resolves the variables an agent named, from the supervisor’s own environment.
Errors
Returns SpawnError::MissingEnv for the first name that is not set.